%bcond_with tests

Summary:        Python HTTP client/server for asyncio
Name:           python-aiohttp
Version:        3.9.5
Release:        1%{?dist}
License:        Apache-2.0
URL:            https://github.com/aio-libs/aiohttp
Source0:        %{url}/archive/v%{version}/aiohttp-%{version}.tar.gz

Patch3000:      0001-Unbundle-llhttp.patch

BuildRequires:  gcc llhttp-devel python3-devel python3dist(cython)
BuildRequires:  llhttp-devel >= 9.2.1


%description
Python HTTP client/server for asyncio which supports both the client and the server side of the HTTP
protocol, client and server websocket, and webservers with middlewares and pluggable routing.

%package -n python3-aiohttp
Summary:        Python HTTP client/server for asyncio
Recommends:     python3-aiohttp+speedups

%description -n python3-aiohttp
Python HTTP client/server for asyncio which supports both the client and the server side of the HTTP
protocol, client and server websocket, and webservers with middlewares and pluggable routing.

%pyproject_extras_subpkg -n python3-aiohttp speedups

%prep
%autosetup -p 1 -n aiohttp-%{version}
rm -rvf vendor/llhttp
sed -r -i '/--cov=/d' setup.cfg
sed -r \
   -e 's/^(proxy[-\.]py|python-on-whales|wait-for-it)/# &/' \
   -e 's/^(coverage|pytest-cov|mypy)/# &/' \
   -e 's/^(setuptools-git)/# &/' \
   -e 's/^-c /# &/' \
   requirements/test.in |
   sed -r 's/^time-machine\b/# /' |
   tee requirements/test.in.filtered

sed -r -i 's/^uvloop\b/# &/' requirements/base.in
grep -rl '/\* Generated by Cython' | xargs -r rm -v

sed -i 's/"-W", "error"/"-W", "error", "-W", "ignore::DeprecationWarning"/' tests/test_circular_imports.py

%generate_buildrequires
%{pyproject_buildrequires \
    requirements/cython.in \
    %{?with_tests:requirements/test.in.filtered}}

%build
mkdir -p .git
%{python3} tools/gen.py
%{python3} -m cython -3 aiohttp/*.pyx -I aiohttp
rm -rvf .git
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files aiohttp

%check
%if %{with tests}
export PYTHONSAFEPATH=1
ignore="${ignore-} --ignore=tests/test_proxy_functional.py"
ignore="${ignore-} --ignore=tests/autobahn"
k="${k-}${k+ and }not test_client_session_timeout_zero"
k="${k-}${k+ and }not test_import_time"
k="${k-}${k+ and }not (TestCookieJarSafe and test_max_age)"
k="${k-}${k+ and }not (TestCookieJarSafe and test_expires)"
k="${k-}${k+ and }not test_cookie_jar_clear_expired"
k="${k-}${k+ and }not test_no_warnings[aiohttp.pytest_plugin]"
k="${k-}${k+ and }not test_send_compress_text"
%pytest -Wdefault ${ignore-} -k "${k-}" -m 'not dev_mode'
%else
###%pyproject_check_import -e aiohttp.pytest_plugin -e aiohttp.worker
%endif

%files -n python3-aiohttp -f %{pyproject_files}
%doc CHANGES.rst
%doc HISTORY.rst
%doc README.rst

%changelog
* Fri May 31 2024 maxonxie <maxonxie@tencent.com> - 3.9.5-1
- Update to 3.9.5 fix CVE-2024-27306

* Tue Mar 05 2024 maxonxie <maxonxie@opencloudos.tech> - 3.9.3-1
- Update to 3.9.3, security  CVE-2024-23334 / CVE-2024-23829 cve update

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.8.4-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.8.4-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.8.4-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 Shuo Wang <abushwang@tencent.com> - 3.8.4-1
- initial build
